--[[
	## Interface: 50001

	## Title: HideHealingText
	## Notes: Removes healing received from the Blizzard Floating Combat Text
	## Author: Sav (weriK)

	v1.0
--]]

-- EVENT HANDLING
-- 

-- First we need to create a frame to capture events
local SAV_HHTFrame = CreateFrame("FRAME");

-- Opt-in to receive the ADDON_LOADED event ( fired when all saved variables are loaded by the game )
SAV_HHTFrame:RegisterEvent("ADDON_LOADED");

-- This handles the events our frame receives
function SAV_HHTFrame:OnEvent(event, arg1)

	-- If our addon variables are loaded
	if event == "ADDON_LOADED" and arg1 == "HideHealingText" then

		-- Check if our saved variable exsists, if not we create a new one, and make sure the addon is turned off by default
		if not SAV_HHTState then
			SAV_HHTState = {};
			SAV_HHTState["showtext"] = true;
		end

		-- If the healing text was hidden during the last session, we make sure it stays turned on
		-- and then notify the user about the current state of the addon.
		if SAV_HHTState["showtext"] == false then
			SAV_HHT_RemoveFloatingText();
			print("HideHealingText loaded, floating healing text is|cFFFF0000 HIDDEN|r! Yee \\o/");	
		else
			print("HideHealingText loaded, floating healing text is|cFF00FF00 SHOWN|r!");
		end

	end
end

-- Set the event handler function for our frame
SAV_HHTFrame:SetScript("OnEvent", SAV_HHTFrame.OnEvent);

-- SLASH COMMAND
--

-- Define our two slash commands
SLASH_SAV_HHTHEALSPAM1 = "/hht";
SLASH_SAV_HHTHEALSPAM2 = "/hhttoggle";

-- Set a function we will execute when the slash command is used
SlashCmdList["SAV_HHTHEALSPAM"] = function()
	SAV_HHT_ToggleHealSpam();
end

-- Toggles the healing text when the slash command is used
function SAV_HHT_ToggleHealSpam()
	-- If the text was hidden, we restore it
	if SAV_HHTState["showtext"] == false then
		SAV_HHTState["showtext"] = true;
		SAV_HHT_RestoreFloatingText();
		print("HideHealingText: Floating healing text is now|cFF00FF00 SHOWN!|r!");

	-- else we hide the healing text
	else
		SAV_HHTState["showtext"] = false;
		SAV_HHT_RemoveFloatingText();
		print("HideHealingText: Floating healing text is now|cFFFF0000 HIDDEN!|r!");
	end

end

-- Hides all healing combat text
function SAV_HHT_RemoveFloatingText()
	COMBAT_TEXT_TYPE_INFO["PERIODIC_HEAL"]["show"]			= nil;
	COMBAT_TEXT_TYPE_INFO["HEAL_CRIT"]["show"]				= nil;
	COMBAT_TEXT_TYPE_INFO["HEAL"]["show"]					= nil;
	COMBAT_TEXT_TYPE_INFO["PERIODIC_HEAL_ABSORB"]["show"]	= nil;
	COMBAT_TEXT_TYPE_INFO["HEAL_CRIT_ABSORB"]["show"]		= nil;
	COMBAT_TEXT_TYPE_INFO["HEAL_ABSORB"]["show"]			= nil;
end

-- Restores all healing text to the default state
function SAV_HHT_RestoreFloatingText()
	COMBAT_TEXT_TYPE_INFO["PERIODIC_HEAL"]["show"]			= 1;
	COMBAT_TEXT_TYPE_INFO["HEAL_CRIT"]["show"]				= 1;
	COMBAT_TEXT_TYPE_INFO["HEAL"]["show"]					= 1;
	COMBAT_TEXT_TYPE_INFO["PERIODIC_HEAL_ABSORB"]["show"]	= 1;
	COMBAT_TEXT_TYPE_INFO["HEAL_CRIT_ABSORB"]["show"]		= 1;
	COMBAT_TEXT_TYPE_INFO["HEAL_ABSORB"]["show"]			= 1;
end
